summaryrefslogtreecommitdiffstats
path: root/kimagemapeditor
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 12:01:04 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 12:01:04 -0600
commit84c989c19db5daab602a67f47ca0f5fd7a2b53d2 (patch)
treedc5875bd392dce2d636a94bebcf5c44a270fac6d /kimagemapeditor
parent9445f97b426e97c6ce46de18fba4030da45d56df (diff)
downloadtdewebdev-84c989c19db5daab602a67f47ca0f5fd7a2b53d2.tar.gz
tdewebdev-84c989c19db5daab602a67f47ca0f5fd7a2b53d2.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kimagemapeditor')
-rw-r--r--kimagemapeditor/drawzone.cpp6
-rw-r--r--kimagemapeditor/drawzone.h2
-rw-r--r--kimagemapeditor/imagemap.cpp2
-rw-r--r--kimagemapeditor/kimagemapeditor.cpp68
-rw-r--r--kimagemapeditor/kimearea.cpp60
-rw-r--r--kimagemapeditor/kimearea.h4
-rw-r--r--kimagemapeditor/kimecommands.cpp20
-rw-r--r--kimagemapeditor/kimedialogs.cpp18
8 files changed, 90 insertions, 90 deletions
diff --git a/kimagemapeditor/drawzone.cpp b/kimagemapeditor/drawzone.cpp
index ba1ea48d..d6fdc2d1 100644
--- a/kimagemapeditor/drawzone.cpp
+++ b/kimagemapeditor/drawzone.cpp
@@ -545,7 +545,7 @@ void DrawZone::contentsMouseMoveEvent(TQMouseEvent *e)
drawCurrent=translateFromZoom(drawCurrent);
if (currentAction==DrawRectangle) {
- // To avoid flicker, only tqrepaint the minimum rect
+ // To avoid flicker, only repaint the minimum rect
TQRect oldRect=translateToZoom(currentArea->rect());
currentArea->setRect(TQRect(drawStart,drawCurrent).normalize());
TQRect newRect=translateToZoom(currentArea->selectionRect());
@@ -629,10 +629,10 @@ void DrawZone::contentsMouseMoveEvent(TQMouseEvent *e)
imageMapEditor->deselectWithoutUpdate( it.current() );
}
*/
- // We don't have to tqrepaint the hole selection rectangle
+ // We don't have to repaint the hole selection rectangle
// only the borders have to be repainted.
// So we have to create 4 rectangles for every rectangle
- // which represent the borders and then tqrepaint them.
+ // which represent the borders and then repaint them.
TQRect lb,rb,tb,bb;
createBorderRectangles(translateToZoom(r),lb,rb,tb,bb);
diff --git a/kimagemapeditor/drawzone.h b/kimagemapeditor/drawzone.h
index 3934a8aa..d9b564a6 100644
--- a/kimagemapeditor/drawzone.h
+++ b/kimagemapeditor/drawzone.h
@@ -97,7 +97,7 @@ private:
KImageMapEditor *imageMapEditor;
// Only the rect of the zoomed image, perhaps redundant
TQRect imageRect;
- // Only for tqrepaint issues
+ // Only for repaint issues
Area *oldArea;
TQRect oldSelectionRect;
diff --git a/kimagemapeditor/imagemap.cpp b/kimagemapeditor/imagemap.cpp
index 04c1908e..4489508d 100644
--- a/kimagemapeditor/imagemap.cpp
+++ b/kimagemapeditor/imagemap.cpp
@@ -259,7 +259,7 @@ void ImageMap::contentsMouseMoveEvent(TQMouseEvent *e) {
drawCurrent=translateFromZoom(drawCurrent);
if (currentAction==DrawRectangle) {
- // To avoid flicker, only tqrepaint the minimum rect
+ // To avoid flicker, only repaint the minimum rect
TQRect oldRect=translateToZoom(currentArea->rect());
currentArea->setRect(TQRect(drawStart,drawCurrent).normalize());
TQRect newRect=translateToZoom(currentArea->rect());
diff --git a/kimagemapeditor/kimearea.cpp b/kimagemapeditor/kimearea.cpp
index 93254d0a..2eb05997 100644
--- a/kimagemapeditor/kimearea.cpp
+++ b/kimagemapeditor/kimearea.cpp
@@ -675,10 +675,10 @@ TQBitmap RectArea::getMask() const
TQString RectArea::coordsToString() const
{
TQString retStr=TQString("%1,%2,%3,%4")
- .tqarg(rect().left())
- .tqarg(rect().top())
- .tqarg(rect().right())
- .tqarg(rect().bottom());
+ .arg(rect().left())
+ .arg(rect().top())
+ .arg(rect().right())
+ .arg(rect().bottom());
return retStr;
}
@@ -747,7 +747,7 @@ bool RectArea::setCoords(const TQString & s)
TQString RectArea::getHTMLCode() const {
TQString retStr;
retStr+="<area ";
- retStr+="tqshape=\"rect\" ";
+ retStr+="shape=\"rect\" ";
retStr+=getHTMLAttributes();
@@ -834,9 +834,9 @@ TQBitmap CircleArea::getMask() const
TQString CircleArea::coordsToString() const
{
TQString retStr=TQString("%1,%2,%3")
- .tqarg(_rect.center().x())
- .tqarg(_rect.center().y())
- .tqarg(_rect.width()/2);
+ .arg(_rect.center().x())
+ .arg(_rect.center().y())
+ .arg(_rect.width()/2);
return retStr;
}
@@ -949,7 +949,7 @@ bool CircleArea::setCoords(const TQString & s)
TQString CircleArea::getHTMLCode() const {
TQString retStr;
retStr+="<area ";
- retStr+="tqshape=\"circle\" ";
+ retStr+="shape=\"circle\" ";
retStr+=getHTMLAttributes();
@@ -1033,8 +1033,8 @@ TQString PolyArea::coordsToString() const
for (uint i=0;i<_coords->count();i++) {
retStr.append(TQString("%1,%2,")
- .tqarg(_coords->point(i).x())
- .tqarg(_coords->point(i).y()));
+ .arg(_coords->point(i).x())
+ .arg(_coords->point(i).y()));
}
retStr.remove(retStr.length()-1,1);
@@ -1224,7 +1224,7 @@ bool PolyArea::setCoords(const TQString & s)
TQString PolyArea::getHTMLCode() const {
TQString retStr;
retStr+="<area ";
- retStr+="tqshape=\"poly\" ";
+ retStr+="shape=\"poly\" ";
retStr+=getHTMLAttributes();
@@ -1283,7 +1283,7 @@ void DefaultArea::draw(TQPainter &)
TQString DefaultArea::getHTMLCode() const {
TQString retStr;
retStr+="<area ";
- retStr+="tqshape=\"default\" ";
+ retStr+="shape=\"default\" ";
retStr+=getHTMLAttributes();
@@ -1302,7 +1302,7 @@ AreaSelection::AreaSelection()
{
_areas = new AreaList();
_name = "Selection";
- tqinvalidate();
+ invalidate();
}
AreaSelection::~AreaSelection() {
@@ -1352,7 +1352,7 @@ void AreaSelection::add(Area *a)
}
}
- tqinvalidate();
+ invalidate();
}
void AreaSelection::remove(Area *a)
@@ -1362,7 +1362,7 @@ void AreaSelection::remove(Area *a)
a->setSelected( false );
_areas->remove( a );
- tqinvalidate();
+ invalidate();
}
void AreaSelection::reset()
@@ -1375,7 +1375,7 @@ void AreaSelection::reset()
}
_areas->clear();
- tqinvalidate();
+ invalidate();
}
bool AreaSelection::contains(const TQPoint & p) const
@@ -1423,7 +1423,7 @@ void AreaSelection::moveSelectionPoint(TQRect* selectionPoint, const TQPoint & p
_areas->getFirst()->moveSelectionPoint(selectionPoint,p);
- tqinvalidate();
+ invalidate();
}
@@ -1436,7 +1436,7 @@ void AreaSelection::moveBy(int dx, int dy)
Area::moveBy( dx, dy );
- tqinvalidate();
+ invalidate();
}
TQString AreaSelection::typeString() const
@@ -1474,7 +1474,7 @@ void AreaSelection::updateSelectionPoints()
it.current()->updateSelectionPoints();
}
- tqinvalidate();
+ invalidate();
}
@@ -1525,7 +1525,7 @@ void AreaSelection::setArea(const Area & copy)
setAreaSelection(*selection);
else {
Area::setArea(copy);
- tqinvalidate();
+ invalidate();
}
}
@@ -1541,14 +1541,14 @@ void AreaSelection::setAreaSelection(const AreaSelection & copy)
it.current()->setArea(*it2.current());
Area::setArea(copy);
- tqinvalidate();
+ invalidate();
}
void AreaSelection::setAreaList( const AreaList & areas )
{
delete _areas;
_areas = new AreaList(areas);
- tqinvalidate();
+ invalidate();
}
void AreaSelection::setRect(const TQRect & r)
@@ -1558,7 +1558,7 @@ void AreaSelection::setRect(const TQRect & r)
_areas->getFirst()->setRect(r);
}
- tqinvalidate();
+ invalidate();
_rect=rect();
updateSelectionPoints();
}
@@ -1586,7 +1586,7 @@ int AreaSelection::addCoord(const TQPoint & p)
if ( _areas->count()==1 )
{
return _areas->getFirst()->addCoord(p);
- tqinvalidate();
+ invalidate();
}
return 0;
@@ -1597,7 +1597,7 @@ void AreaSelection::insertCoord(int pos, const TQPoint & p)
if ( _areas->count()==1 )
{
_areas->getFirst()->insertCoord(pos, p);
- tqinvalidate();
+ invalidate();
}
}
@@ -1606,7 +1606,7 @@ void AreaSelection::removeCoord(int pos)
if ( _areas->count()==1 )
{
_areas->getFirst()->removeCoord(pos);
- tqinvalidate();
+ invalidate();
}
}
@@ -1617,7 +1617,7 @@ bool AreaSelection::removeSelectionPoint(TQRect * r)
if ( _areas->count()==1 )
{
result = _areas->getFirst()->removeSelectionPoint(r);
- tqinvalidate();
+ invalidate();
}
return result;
@@ -1639,7 +1639,7 @@ void AreaSelection::moveCoord(int pos,const TQPoint & p)
if ( _areas->count()==1 )
{
_areas->getFirst()->moveCoord(pos,p);
- tqinvalidate();
+ invalidate();
}
}
@@ -1648,7 +1648,7 @@ void AreaSelection::highlightSelectionPoint(int i)
if ( _areas->count()==1 )
{
_areas->getFirst()->highlightSelectionPoint(i);
- tqinvalidate();
+ invalidate();
}
}
diff --git a/kimagemapeditor/kimearea.h b/kimagemapeditor/kimearea.h
index 3274a322..0c554754 100644
--- a/kimagemapeditor/kimearea.h
+++ b/kimagemapeditor/kimearea.h
@@ -367,7 +367,7 @@ class AreaSelection : public Area {
bool allAreasWithin(const TQRect & r) const;
// makes the cache invalid
- void tqinvalidate();
+ void invalidate();
private :
AreaList *_areas;
@@ -382,7 +382,7 @@ class AreaSelection : public Area {
};
-inline void AreaSelection::tqinvalidate() {
+inline void AreaSelection::invalidate() {
_selectionCacheValid=false;
_rectCacheValid=false;
}
diff --git a/kimagemapeditor/kimecommands.cpp b/kimagemapeditor/kimecommands.cpp
index 817d8b7d..975001d9 100644
--- a/kimagemapeditor/kimecommands.cpp
+++ b/kimagemapeditor/kimecommands.cpp
@@ -30,7 +30,7 @@ KCommand
#else
KNamedCommand
#endif
- (i18n( "Cut %1" ).tqarg( a.typeString() ))
+ (i18n( "Cut %1" ).arg( a.typeString() ))
{
_document=document;
_cutAreaSelection=new AreaSelection();
@@ -74,7 +74,7 @@ void CutCommand::unexecute()
DeleteCommand::DeleteCommand(KImageMapEditor * document, const AreaSelection & a)
: CutCommand(document,a)
{
- setName(i18n( "Delete %1" ).tqarg( a.typeString() ));
+ setName(i18n( "Delete %1" ).arg( a.typeString() ));
}
PasteCommand::PasteCommand(KImageMapEditor *document, const AreaSelection & a)
@@ -84,7 +84,7 @@ KCommand
#else
KNamedCommand
#endif
- (i18n( "Paste %1" ).tqarg( a.typeString() ))
+ (i18n( "Paste %1" ).arg( a.typeString() ))
{
_document=document;
_pasteAreaSelection=new AreaSelection();
@@ -129,7 +129,7 @@ KCommand
#else
KNamedCommand
#endif
-(i18n( "Move %1" ).tqarg( a->typeString() ))
+(i18n( "Move %1" ).arg( a->typeString() ))
{
_document=document;
_areaSelection=new AreaSelection();
@@ -155,7 +155,7 @@ void MoveCommand::execute()
if (!_areaSelection->allAreasWithin(_document->getDrawZone()->getImageRect()))
_areaSelection->moveTo( _oldPoint.x(), _oldPoint.y() );
- _document->selected()->tqinvalidate();
+ _document->selected()->invalidate();
_document->slotAreaChanged( tempArea );
@@ -174,7 +174,7 @@ void MoveCommand::unexecute()
_areaSelection->moveTo( _oldPoint.x(), _oldPoint.y() );
_areaSelection->setMoving(false);
- _document->selected()->tqinvalidate();
+ _document->selected()->invalidate();
_document->slotAreaChanged( tempArea );
_document->slotAreaChanged( _areaSelection );
@@ -191,7 +191,7 @@ KCommand
#else
KNamedCommand
#endif
-(i18n( "Resize %1" ).tqarg( a->typeString() ))
+(i18n( "Resize %1" ).arg( a->typeString() ))
{
_areaSelection=new AreaSelection();
_areaSelection->setAreaList( a->getAreaList() );
@@ -238,7 +238,7 @@ KCommand
#else
KNamedCommand
#endif
-(i18n( "Add point to %1" ).tqarg( a->typeString() ))
+(i18n( "Add point to %1" ).arg( a->typeString() ))
{
if (a->type()!=Area::Polygon)
{
@@ -287,7 +287,7 @@ KCommand
#else
KNamedCommand
#endif
-(i18n( "Remove point from %1" ).tqarg( a->typeString() ))
+(i18n( "Remove point from %1" ).arg( a->typeString() ))
{
if (a->type()!=Area::Polygon)
{
@@ -340,7 +340,7 @@ KCommand
#else
KNamedCommand
#endif
-(i18n( "Create %1" ).tqarg( area->typeString() ))
+(i18n( "Create %1" ).arg( area->typeString() ))
{
_document=document;
_area=area;
diff --git a/kimagemapeditor/kimedialogs.cpp b/kimagemapeditor/kimedialogs.cpp
index 096f224f..80cf621e 100644
--- a/kimagemapeditor/kimedialogs.cpp
+++ b/kimagemapeditor/kimedialogs.cpp
@@ -423,16 +423,16 @@ AreaDialog::AreaDialog(KImageMapEditor* parent,Area * a)
setCaption(i18n("Area Tag Editor"));
area=a;
- TQString tqshape="Default";
+ TQString shape="Default";
areaCopy= a->clone();
oldArea= new Area();
oldArea->setRect( a->rect() );
switch (a->type()) {
- case Area::Rectangle : tqshape=i18n("Rectangle");break;
- case Area::Circle : tqshape=i18n("Circle");break;
- case Area::Polygon : tqshape=i18n("Polygon");break;
- case Area::Selection : tqshape=i18n("Selection");break;
+ case Area::Rectangle : shape=i18n("Rectangle");break;
+ case Area::Circle : shape=i18n("Circle");break;
+ case Area::Polygon : shape=i18n("Polygon");break;
+ case Area::Selection : shape=i18n("Selection");break;
default : break;
}
@@ -443,7 +443,7 @@ AreaDialog::AreaDialog(KImageMapEditor* parent,Area * a)
tqlayout->setMargin(5);
- TQLabel *lbl = new TQLabel("<b>"+tqshape+"</b>",this);
+ TQLabel *lbl = new TQLabel("<b>"+shape+"</b>",this);
lbl->setTextFormat(TQt::RichText);
tqlayout->addWidget(lbl);
@@ -460,7 +460,7 @@ AreaDialog::AreaDialog(KImageMapEditor* parent,Area * a)
if (a->type()==Area::Default)
{
- tqshape=i18n("Default");
+ shape=i18n("Default");
}
else
tab->addTab(createCoordsPage(),i18n("Coor&dinates"));
@@ -731,7 +731,7 @@ void ImageMapChooseDialog::slotImageChanged()
pix2.convertFromImage(pix);
imagePreview->setPixmap(pix2);
-// imagePreview->tqrepaint();
+// imagePreview->repaint();
}
void ImageMapChooseDialog::selectImageWithUsemap(const TQString & usemap) {
@@ -867,7 +867,7 @@ void HTMLPreviewDialog::show() {
KDialogBase::show();
htmlPart->openURL(KURL( tempFile->name() ));
// htmlView->tqlayout();
-// htmlView->tqrepaint();
+// htmlView->repaint();
resize(800,600);
}
diff --git a/kimagemapeditor/kimagemapeditor.cpp b/kimagemapeditor/kimagemapeditor.cpp
index 6dbb1a32..ca2b7ba7 100644
--- a/kimagemapeditor/kimagemapeditor.cpp
+++ b/kimagemapeditor/kimagemapeditor.cpp
@@ -396,7 +396,7 @@ void KImageMapEditor::slotConfigChanged()
}
updateAllAreas();
- drawZone->viewport()->tqrepaint();
+ drawZone->viewport()->repaint();
}
void KImageMapEditor::openLastURL(KConfig* config) {
@@ -425,7 +425,7 @@ void KImageMapEditor::saveLastURL(KConfig* config) {
// kdDebug() << "writing entry lastopenurl : " << url().path() << endl;
// kdDebug() << "writing entry lastactivemap : " << mapName() << endl;
// kdDebug() << "writing entry lastactiveimage : " << _imageUrl.path() << endl;
- //KMessageBox::information(0L, TQString("Group: %1 Saving ... %2").tqarg(config->group()).tqarg(url().path()));
+ //KMessageBox::information(0L, TQString("Group: %1 Saving ... %2").arg(config->group()).arg(url().path()));
}
void KImageMapEditor::setupActions()
@@ -736,7 +736,7 @@ void KImageMapEditor::showPopupMenu(const TQPoint & pos, const TQString & name)
TQPopupMenu* pop = static_cast<TQPopupMenu *>(factory()->container(name, this));
if (!pop) {
- kdWarning() << TQString("KImageMapEditorPart: Missing XML definition for %1\n").tqarg(name) << endl;
+ kdWarning() << TQString("KImageMapEditorPart: Missing XML definition for %1\n").arg(name) << endl;
return;
}
@@ -794,8 +794,8 @@ void KImageMapEditor::updateStatusBar()
void KImageMapEditor::slotChangeStatusCoords(int x,int y)
{
-// statusBar()->changeItem(TQString(" Cursor : x: %1 ,y: %2 ").tqarg(x).tqarg(y),STATUS_CURSOR);
- cursorStatusText = i18n(" Cursor: x: %1, y: %2 ").tqarg(x).tqarg(y);
+// statusBar()->changeItem(TQString(" Cursor : x: %1 ,y: %2 ").arg(x).arg(y),STATUS_CURSOR);
+ cursorStatusText = i18n(" Cursor: x: %1, y: %2 ").arg(x).arg(y);
updateStatusBar();
}
@@ -803,7 +803,7 @@ void KImageMapEditor::slotUpdateSelectionCoords() {
if (selected()->count()>0) {
TQRect r=selected()->rect();
// statusBar()->changeItem(
- selectionStatusText = i18n(" Selection: x: %1, y: %2, w: %3, h: %4 ").tqarg(r.left()).tqarg(r.top()).tqarg(r.width()).tqarg(r.height());
+ selectionStatusText = i18n(" Selection: x: %1, y: %2, w: %3, h: %4 ").arg(r.left()).arg(r.top()).arg(r.width()).arg(r.height());
// ,STATUS_SELECTION);
kapp->processEvents();
@@ -816,7 +816,7 @@ void KImageMapEditor::slotUpdateSelectionCoords() {
void KImageMapEditor::slotUpdateSelectionCoords( const TQRect & r )
{
- selectionStatusText = i18n(" Selection: x: %1, y: %2, w: %3, h: %4 ").tqarg(r.left()).tqarg(r.top()).tqarg(r.width()).tqarg(r.height());
+ selectionStatusText = i18n(" Selection: x: %1, y: %2, w: %3, h: %4 ").arg(r.left()).arg(r.top()).arg(r.width()).arg(r.height());
updateStatusBar();
kapp->processEvents();
}
@@ -990,7 +990,7 @@ void KImageMapEditor::deleteArea( Area * area )
{
if (!area) return;
// only for tqrepaint reasons
TQRect redrawRect = area->selectionRect();
// Perhaps we've got a selection of areas
@@ -1055,7 +1055,7 @@ void KImageMapEditor::deleteAllAreas()
a=areas->first(); // because the current is deleted
}
- drawZone->viewport()->tqrepaint();
+ drawZone->viewport()->repaint();
}
@@ -1065,7 +1065,7 @@ void KImageMapEditor::updateAllAreas()
for (Area* a=areas->first();a!=0L;a=areas->next()) {
a->listViewItem()->setPixmap(1,makeListViewPix(*a));
}
- drawZone->viewport()->tqrepaint();
+ drawZone->viewport()->repaint();
}
void KImageMapEditor::updateSelection() const {
@@ -1407,10 +1407,10 @@ void KImageMapEditor::setPicture(const KURL & url) {
imageUsemapAction->setEnabled(true);
}
else
- kdError() << TQString("The image %1 could not be opened.").tqarg(url.path()) << endl;
+ kdError() << TQString("The image %1 could not be opened.").arg(url.path()) << endl;
}
else
- kdError() << TQString("The image %1 does not exist.").tqarg(url.path()) << endl;
+ kdError() << TQString("The image %1 does not exist.").arg(url.path()) << endl;
}
void KImageMapEditor::setPicture(const TQImage & pix) {
@@ -1519,7 +1519,7 @@ void KImageMapEditor::mapEditName()
if (ok) {
if (input != _mapName) {
if (mapsListView->nameAlreadyExists(input))
- KMessageBox::sorry(this->widget(), i18n("The name <em>%1</em> already exists.").tqarg(input));
+ KMessageBox::sorry(this->widget(), i18n("The name <em>%1</em> already exists.").arg(input));
else {
setMapName(input);
}
@@ -1622,12 +1622,12 @@ void KImageMapEditor::fileSaveAs() {
if ( fileInfo.exists() )
{
if (KMessageBox::warningContinueCancel(widget(),
- i18n("<qt>The file <em>%1</em> already exists.<br>Do you want to overwrite it?</qt>").tqarg(fileInfo.fileName()),
+ i18n("<qt>The file <em>%1</em> already exists.<br>Do you want to overwrite it?</qt>").arg(fileInfo.fileName()),
i18n("Overwrite File?"), i18n("Overwrite"))==KMessageBox::Cancel)
return;
if(!fileInfo.isWritable()) {
- KMessageBox::sorry(widget(), i18n("<qt>You do not have write permission for the file <em>%1</em>.</qt>").tqarg(fileInfo.fileName()));
+ KMessageBox::sorry(widget(), i18n("<qt>You do not have write permission for the file <em>%1</em>.</qt>").arg(fileInfo.fileName()));
return;
}
}
@@ -1646,14 +1646,14 @@ bool KImageMapEditor::openFile()
if ( !fileInfo.exists() )
{
KMessageBox::information(widget(),
- i18n("<qt>The file <b>%1</b> does not exist.</qt>").tqarg(fileInfo.fileName()),
+ i18n("<qt>The file <b>%1</b> does not exist.</qt>").arg(fileInfo.fileName()),
i18n("File Does Not Exist"));
return false;
}
openHTMLFile(url());
- drawZone->viewport()->tqrepaint();
+ drawZone->viewport()->repaint();
recentFilesAction->addURL(url());
setModified(false);
backupFileCreated = false;
@@ -2107,16 +2107,16 @@ void KImageMapEditor::saveAreasToMapTag(MapTag* map) {
map->clear();
for (Area* a=areas->first();a!=0L;a=areas->next()) {
TQDict<TQString> *dict = new TQDict<TQString>(17,false);
- TQString *tqshapeStr = 0L;
+ TQString *shapeStr = 0L;
switch (a->type()) {
- case Area::Rectangle : tqshapeStr = new TQString("rect");break;
- case Area::Circle : tqshapeStr = new TQString("circle");break;
- case Area::Polygon : tqshapeStr = new TQString("poly");break;
+ case Area::Rectangle : shapeStr = new TQString("rect");break;
+ case Area::Circle : shapeStr = new TQString("circle");break;
+ case Area::Polygon : shapeStr = new TQString("poly");break;
default : continue;
}
- dict->insert("tqshape",tqshapeStr);
+ dict->insert("shape",shapeStr);
for (AttributeIterator it = a->firstAttribute();it!=a->lastAttribute();++it) {
dict->insert(it.key(),new TQString(it.data()));
@@ -2130,7 +2130,7 @@ void KImageMapEditor::saveAreasToMapTag(MapTag* map) {
if (defaultArea && defaultArea->finished()) {
TQDict<TQString> *dict = new TQDict<TQString>(17,false);
- dict->insert("tqshape",new TQString("default"));
+ dict->insert("shape",new TQString("default"));
for (AttributeIterator it = defaultArea->firstAttribute();it!=defaultArea->lastAttribute();++it) {
dict->insert(it.key(),new TQString(it.data()));
@@ -2159,16 +2159,16 @@ void KImageMapEditor::setMap(HtmlMapElement* mapElement) {
_mapName = map->name;
for (AreaTag *tag=map->first();tag!=0L;tag=map->next())
{
- TQString tqshape="rect";
- if (tag->find("tqshape"))
- tqshape=*tag->find("tqshape");
+ TQString shape="rect";
+ if (tag->find("shape"))
+ shape=*tag->find("shape");
Area::ShapeType type=Area::Rectangle;
- if (tqshape=="circle")
+ if (shape=="circle")
type=Area::Circle;
- else if (tqshape=="poly")
+ else if (shape=="poly")
type=Area::Polygon;
- else if (tqshape=="default")
+ else if (shape=="default")
type=Area::Default;
Area* a=AreaCreator::create(type);
@@ -2267,7 +2267,7 @@ void KImageMapEditor::saveImageMap(const KURL & url)
if (!TQFileInfo(url.directory()).isWritable()) {
KMessageBox::error(widget(),
- i18n("<qt>The file <i>%1</i> could not be saved, because you do not have the required write permissions.</qt>").tqarg(url.path()));
+ i18n("<qt>The file <i>%1</i> could not be saved, because you do not have the required write permissions.</qt>").arg(url.path()));
return;
}
@@ -2556,7 +2556,7 @@ void KImageMapEditor::slotHightlightAreas()
// highlightAreasAction->setChecked(b);
Area::highlightArea = b;
updateAllAreas();
- drawZone->viewport()->tqrepaint();
+ drawZone->viewport()->repaint();
}
void KImageMapEditor::slotShowAltTag()
@@ -2564,7 +2564,7 @@ void KImageMapEditor::slotShowAltTag()
bool b = showAltAction->isChecked();
// showAltAction->setChecked(b);
Area::showAlt = b;
- drawZone->viewport()->tqrepaint();
+ drawZone->viewport()->repaint();
}
void KImageMapEditor::mapNew()
@@ -2583,7 +2583,7 @@ void KImageMapEditor::mapDelete()
int result = KMessageBox::warningContinueCancel(widget(),
i18n("<qt>Are you sure you want to delete the map <i>%1</i>?"
- " <br><b>There is no way to undo this.</b></qt>").tqarg(selectedMap),
+ " <br><b>There is no way to undo this.</b></qt>").arg(selectedMap),
i18n("Delete Map?"),KGuiItem(i18n("&Delete"),"editdelete"));
if (result == KMessageBox::No)
@@ -2631,7 +2631,7 @@ bool KImageMapEditor::queryClose() {
return true;
switch ( KMessageBox::warningYesNoCancel( widget(),
- i18n("<qt>The file <i>%1</i> has been modified.<br>Do you want to save it?</qt>").tqarg(url().fileName()), TQString(), KStdGuiItem::save(), KStdGuiItem::discard()) ) {
+ i18n("<qt>The file <i>%1</i> has been modified.<br>Do you want to save it?</qt>").arg(url().fileName()), TQString(), KStdGuiItem::save(), KStdGuiItem::discard()) ) {
case KMessageBox::Yes :
saveFile();
return true;
@@ -990,7 +990,7 @@ void KImageMapEditor::deleteArea( Area * area )
{
if (!area) return;
- // only for tqrepaint reasons
+ // only for repaint reasons
TQRect redrawRect = area->selectionRect();
// Perhaps we've got a selection of areas